@@ -34,16 +34,20 @@
 #include <caml/mlvalues.h>
 #include <caml/misc.h>
 
+#include "ocaml_ladspa_config.h"
+
+#ifdef HAS_LADSPA
 #include <ladspa.h>
+#else
+#include "ladspa.h"
+#endif
 
 typedef struct
 {
   LADSPA_Descriptor *descr;
   LADSPA_Handle handle;
-  LADSPA_Data **buf;
-  int *offset;
+  LADSPA_Data *control_data;
   value *vbuf;
-  int samples;
 } ladspa_instance;
 
 #define Instance_val(v) (*((ladspa_instance**)Data_custom_val(v)))
